Version History — Toy_Coronagraph 1.6.1 documentation

Skip to main content
`Ctrl`+`K`

# Version History

## v1.5.2

published on Aug 28, 2023.

able to add moving planets

## v1.5.3

published on Sep 8, 2023.

normalization of psfs

Users can now set the number of cores to use for parallel computing

feature allow user to ignore dust inside IWA

show the planet brightness unit

print planet brightness and dust brightness

turn on/off dust inside IWA

auto check multithreading module before using it in psf.py

## v1.5.4

published on Sep 12, 2023.

flip or not flip y-axis

you could choose lyot_mask_size in toycoronagraph_para.py

check planet order inputs are positive integers

## v1.6.0

published on Sep 14, 2023.

core_throughput plot

video of planet moving

optimate the parameter number

## v1.6.1

published on Sep 15, 2023.

complete python docstrings for all new features